@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.0.2');
+use version; our $VERSION = qv('0.0.3');
 
 # Other recommended modules (uncomment to use):
 #  use IO::Prompt;
@@ -27,7 +27,7 @@ sub new {
   $self->{start_url} = 'http://k2k.sagawa-exp.co.jp/m/top.do';
   $mech->agent_alias( 'Windows IE 6' );
   $self->{mech} = $mech;
-
+  $self->{user_agent} = __PACKAGE__;
   return bless $self, $class;
 }
  
@@ -88,6 +88,7 @@ sub _request {
     foreach my $key ( keys %$item ) {
       $item2->{$key} = encode_utf8( $item->{$key} );
     }
+    $item2->{user_agent} = $self->{user_agent};
     push @$res2, $item2;
   }
   $res->{results} = $res2;
